==> estateplat-common-1.2.4-20201119.111532-523-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxGaRkSfhc.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-公安-人口-身份核查
 */
@Table(name = "xxgx_ga_rk_sfhc")
public class XxgxGaRkSfhc {
    @Id
    private String sfhcid;//身份核查id
    private String gmxm;//公民姓名
    private String gmsfh;//公民身份号
    private String sfzhppd;//公民身份证号匹配度代码
    private String xmppd;//姓名匹配度
    private String swbs;//死亡标识
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getSfhcid() {
        return sfhcid;
    }

    public void setSfhcid(String sfhcid) {
        this.sfhcid = sfhcid;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getGmsfh() {
        return gmsfh;
    }

    public void setGmsfh(String gmsfh) {
        this.gmsfh = gmsfh;
    }

    public String getSfzhppd() {
        return sfzhppd;
    }

    public void setSfzhppd(String sfzhppd) {
        this.sfzhppd = sfzhppd;
    }

    public String getXmppd() {
        return xmppd;
    }

    public void setXmppd(String xmppd) {
        this.xmppd = xmppd;
    }

    public String getSwbs() {
        return swbs;
    }

    public void setSwbs(String swbs) {
        this.swbs = swbs;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}

==> estateplat-common-1.2.4-20210425.022000-735-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxGaRkSfhc.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-公安-人口-身份核查
 */
@Table(name = "xxgx_ga_rk_sfhc")
public class XxgxGaRkSfhc {
    @Id
    private String sfhcid;//身份核查id
    private String gmxm;//公民姓名
    private String gmsfzh;//公民身份号
    private String sfzhppd;//公民身份证号匹配度代码
    private String xmppd;//姓名匹配度
    private String swbs;//死亡标识
    private String proid;//项目id
    private String qlrid;//权利人id

    public String getSfhcid() {
        return sfhcid;
    }

    public void setSfhcid(String sfhcid) {
        this.sfhcid = sfhcid;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getGmsfzh() {
        return gmsfzh;
    }

    public void setGmsfzh(String gmsfzh) {
        this.gmsfzh = gmsfzh;
    }

    public String getSfzhppd() {
        return sfzhppd;
    }

    public void setSfzhppd(String sfzhppd) {
        this.sfzhppd = sfzhppd;
    }

    public String getXmppd() {
        return xmppd;
    }

    public void setXmppd(String xmppd) {
        this.xmppd = xmppd;
    }

    public String getSwbs() {
        return swbs;
    }

    public void setSwbs(String swbs) {
        this.swbs = swbs;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}
